@@ -4,6 +4,8 @@ from functools import reduce
 from random import choice
 from string import ascii_letters
 from importlib import import_module
+import shutil
+import zipfile
 
 
 def deep_merge(*dicts, update=False):
@@ -110,25 +112,81 @@ def inst_has_typename(inst, types):
 
 def is_keras_model(inst):
     """
-    Check whether an inst is instance of keras model
+    Check whether `inst` is instance of keras model
     """
     return inst_has_typename(inst, ['keras', 'Model'])
 
 
 def is_pytorch_module(inst):
     """
-    Check whether an inst is instance of pytorch module
+    Check whether `inst` is instance of pytorch module
     """
     return inst_has_typename(inst, ['torch', 'Module'])
 
 
+def is_tensorflow_session(inst):
+    """
+    Check whether `inst` is instance of tensorflow session
+    """
+    return inst_has_typename(inst, ['tensorflow', 'session'])
+
+
+def is_tensorflow_estimator(inst):
+    """
+    Check whether `inst` is instance of tensorflow estimator
+    """
+    return inst_has_typename(inst, ['tensorflow', 'estimator'])
+
+
 def is_pytorch_optim(inst):
     """
-    Check whether an inst is instance of pytorch optimizer
+    Check whether `inst` is instance of pytorch optimizer
     """
     return inst_has_typename(inst, ['torch', 'optim'])
 
 
+def is_pytorch_tensor(inst):
+    """
+    Check whether `inst` is instance of pytorch tensor
+    """
+    return inst_has_typename(inst, ['torch', 'Tensor'])
+
+
+def is_numpy_array(inst):
+    """
+    Check whether `inst` is instance of numpy array
+    """
+    return inst_has_typename(inst, ['numpy', 'ndarray'])
+
+
+def is_numpy_number(inst):
+    """
+    Check whether `inst` is numpy number and convert to python native type
+    """
+    if inst_has_typename(inst, ['numpy']):
+        converted_val = inst.item()
+        if isinstance(converted_val, (int, float)):
+            return True, converted_val
+    return False, None
+
+
+def convert_to_py_number(value):
+    """
+    Converts numpy objects or tensors to python number types
+    """
+    if isinstance(value, (int, float)):
+        return value
+
+    np_number, converted_val = is_numpy_number(value)
+    if np_number:
+        return converted_val
+
+    if is_pytorch_tensor(value):
+        return value.item()
+
+    return value
+
+
 def get_module(name, required=True):
     """
     Return specified module or None otherwise,
@@ -138,5 +196,38 @@ def get_module(name, required=True):
         return import_module(name)
     except Exception:
         if required:
-            raise ValueError('No module named: \'{}\''.format(name))
+            raise ValueError('no module named: \'{}\''.format(name))
         return None
+
+
+def archive_dir(zip_path, dir_path):
+    """
+    Archive a directory
+    """
+    zip_file = zipfile.ZipFile(zip_path, 'w')
+    with zip_file:
+        # Writing each file one by one
+        for file in ls_dir([dir_path]):
+            zip_file.write(file, file[len(dir_path):])
+
+    # Remove model directory
+    shutil.rmtree(dir_path)
+
+
+def clean_repo_path(repo_path: str) -> str:
+    if not isinstance(repo_path, str) or not repo_path:
+        return ''
+
+    repo_path = repo_path.strip().rstrip('/')
+
+    if repo_path == '.':
+        return os.getcwd()
+    if repo_path == '~':
+        return os.path.expanduser('~')
+
+    if repo_path.endswith('.aim'):
+        repo_path = repo_path[:-4]
+    if repo_path.startswith('~'):
+        repo_path = os.path.expanduser('~') + repo_path[1:]
+
+    return os.path.abspath(repo_path)
